import pickle

import cloudscraper
import colorama
import json
import time
import datetime
import os
from termcolor import colored
import random, bs4
from requests.utils import cookiejar_from_dict as jar
import os, requests
import sys
from tinydb import TinyDB, Query,where
from cryptography import fernet

encryption_key = b'tUvzG-BWuh2xQB1k4VKynl4ox_2k9VHCMjRe4-UOQgA='
User = Query()

colorama.init()

db = TinyDB('database.json')


class MainBot:
    def __init__(self):
        self.win_instance =None

        self.status=""

        self.hashtags=[]
        self.target_usernames=[]

        self.comments=[]

        self.obtained_users_posts={}

        self.stop_running_bot=False

        '''change this to 1000'''

        self.max_likes = 1000
        self.max_comments = 200

        self.liked_today = 0
        self.comment_today = 0
        self.now = datetime.datetime.today()

    def login_user(self,username,password,db_connector):

        colorama.init()
        self.cookies_expired = False

        self.db=db_connector

        credentials = self.db.search(User.credentials == 'true')

        if credentials:
            # print(credentials)
            encrypt_creds = fernet.Fernet(encryption_key)

            decrypt_credentials = credentials[0].get("encrypted").encode()
            cookies = encrypt_creds.decrypt(credentials[0].get("login_cookies").encode())

            decrypt_cryptography = encrypt_creds.decrypt(decrypt_credentials)
            decrypt_pickle2 = pickle.loads(decrypt_cryptography)
            self.username = decrypt_pickle2.get("username", "specify a username")
            self.password = decrypt_pickle2.get("password", "specify a password")

        else:
            self.username = username
            self.password = password
            cookies = None

        '''if they have the cookies file use it'''

        liked_ = self.db.search(User[f"{self.username}_date_today"] == str(self.now).split(" ")[0])

        if liked_:
            self.liked_today = liked_[0].get("liked_today")
            self.comment_today = liked_[0].get("comment_today")
            print(
                colored(f" [   ]{self.liked_today}  Liked today  ---  {self.comment_today} commented on today", "blue"))
        else:
            self.db.insert({f"{self.username}_date_today": str(self.now).split(" ")[0], "liked_today": self.liked_today,
                            "comment_today": self.comment_today})

        self.track_liked_and_comments()

        if cookies:
                cj = pickle.loads(cookies)
                for cookie in cj:
                    if cookie.is_expired():
                        self.cookies_expired = True
                        print("cookie expired")

                        self.db.remove(where("credentials") == 'true')

                self.scraper = requests.Session()
                self.scraper.cookies = cj

                self.csrf_token = self.scraper.cookies.get_dict()['csrftoken']

                '''update headers'''
                headers = {
                    'user-agent': 'Mozilla/5.0 (iPhone; CPU iPhone OS 12_3_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, '
                                  'like Gecko) Mobile/15E148 Instagram 105.0.0.11.118 (iPhone11,8; iOS 12_3_1; en_US; en-US; '
                                  'scale=2.00; 828x1792; 165586599) '
                }

                self.scraper.headers.update(headers)

                user = self.scraper.get(f"https://www.instagram.com/{self.username}/")

                logged_user = str(bs4.BeautifulSoup(user.text, 'lxml').title.text).split('•')[0]
                logged_user_ = str(logged_user).replace("is on Instagram", " ")

                print(colored(f"[+] {time.ctime()} logged in as {logged_user_} via cookies", "green"), end="\n\n")
                self.status=f"logged in as {logged_user_} using cookie session"
                self.return_status(self.status)

                timer=random.randrange(15,40)
                for e in range(timer):
                    progress_=round(e/timer*100)
                    self.return_status(f"startup process initiated {progress_}% complete")
                    time.sleep(1)

                    if self.stop_running_bot:
                        self.status = "stopping bot"
                        self.return_status(self.status)
                        break

                return "logged in"

        else:
            return self.expired_cookies()

    def expired_cookies(self):
        self.scraper = cloudscraper.create_scraper()
        self.time = int(datetime.datetime.now().timestamp())

        self.link = 'https://www.instagram.com/accounts/login/'
        self.login_url = 'https://www.instagram.com/accounts/login/ajax/'

        response = self.scraper.get(self.link)
        self.csrf = response.cookies.get("csrftoken")

        self.csrf_token = None

        self.payload = {
            'username': self.username,
            'enc_password': f'#PWD_INSTAGRAM_BROWSER:0:{self.time}:{self.password}',
            'queryParams': {},
            'optIntoOneTap': 'false'
        }
        self.login_header = {
            'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.36 (KHTML, like Gecko) '
                          'Chrome/49.0.2623.112 Safari/537.36',
            "X-Requested-With": "XMLHttpRequest",
            "Referer": "https://www.instagram.com/accounts/login/",
            "x-csrftoken": self.csrf
        }

        self.scraper = cloudscraper.CloudScraper()



        self.headers = {
            'user-agent': 'Mozilla/5.0 (iPhone; CPU iPhone OS 12_3_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, '
                          'like Gecko) Mobile/15E148 Instagram 105.0.0.11.118 (iPhone11,8; iOS 12_3_1; en_US; en-US; '
                          'scale=2.00; 828x1792; 165586599) ',
            "x-csrftoken": self.csrf_token
        }

        return self.login()

    def login(self):

        login_response = self.scraper.post(self.login_url, data=self.payload, headers=self.login_header)

        json_data = json.loads(login_response.text)
        print(json_data)
        if json_data.get("authenticated"):
            print(colored("login successful", "green"))
            self.status="login successful"

            cookies = login_response.cookies
            cookie_jar = cookies.get_dict()

            self.csrf_token = cookie_jar['csrftoken']
            print("csrf_token: ", self.csrf_token)
            session_id = cookie_jar['sessionid']
            user_id = cookie_jar['ds_user_id']
            print("session_id: ", session_id)

            encrypt_creds = fernet.Fernet(encryption_key)

            credentials = {"username": self.username, "password": self.password}
            pickled_credentials = pickle.dumps(credentials)
            encrypted = encrypt_creds.encrypt(pickled_credentials)

            encrypt_cookies=encrypt_creds.encrypt(pickle.dumps(cookies))

            self.db.insert({"encrypted": encrypted.decode("utf-8"),"login_cookies":encrypt_cookies.decode("utf-8"),"credentials": "true"})

            return "successful first login"

        else:
            print(colored(f"login failed {login_response.text}", "red"), end="\n\n")

            if "wait" in login_response.text:
                print(colored("! wait a couple of hours before trying again", "magenta"))
                return "! login failed, wait a couple of hours before trying again"

            else:
                if login_response.json()["user"]:
                    print(colored(f"! login failed, wrong password for user {self.username}", "red"))

                    return f"login failed ,wrong password for user {self.username}"

                else:
                    return f"!login failed, invalid user {self.username}", "red"

    def like_and_comment(self, post_id, post_username):
        print(post_id)
        self.status = f"{post_id}"
        self.return_status(self.status)

        print("\n")

        new_header = {
            'content-length': '0',
            'user-agent': 'Mozilla/5.0 (iPhone; CPU iPhone OS 12_3_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, '
                          'like Gecko) Mobile/15E148 Instagram 105.0.0.11.118 (iPhone11,8; iOS 12_3_1; en_US; '
                          'en-US; '
                          'scale=2.00; 828x1792; 165586599) ',
            "x-csrftoken": self.csrf_token}
        try:

            if self.update_liked(post_id) == "seen before":
                pass

            else:

                time_out_count = [count * 50 for count in range(1,20)]

                if self.liked_today in time_out_count:
                    '''timeout sleep'''
                    self.sleep_bot(timer=random.randrange(900, 1200), reason=" ⌛ like function time out ")

                liked_post = self.scraper.post(f"https://i.instagram.com/api/v1/web/likes/{post_id}/like/",
                                               headers=new_header)

                self.liked_today += 1

                print(colored(str(liked_post.json()), "green"))

                bar_val = round(self.liked_today / self.max_likes * 100)

                self.status = f"successfully liked {post_id} by {post_username} |{bar_val}"
                self.return_status(self.status)
                time.sleep(2)

                print("")

                try:
                    if len(self.comments)>=1:
                        set_timer=random.randrange(25,45)
                        for comment_count in range(set_timer):
                            self.status = f"posting comment on {post_id} {round(comment_count/set_timer*100)} "
                            self.return_status(self.status)
                            time.sleep(1)

                        random.shuffle(self.comments)

                        comment=self.comments[0]

                        comment_Post=self.scraper.post(f"https://i.instagram.com/api/v1/web/comments/{post_id}/add/",data={"comment_text":comment},
                                                       headers=new_header)
                        print(comment_Post.json())

                        bar_val=round(self.comment_today / self.max_comments * 100)
                        self.status = f"successfully commented on {post_id} by {post_username} |{bar_val}"
                        self.return_status(self.status)

                        self.comment_today+=1

                except Exception as e:
                    print(e)

            self.db.update(
                {f"{self.username}_date_today": str(self.now).split(" ")[0], "liked_today": self.liked_today,
                 "comment_today": self.comment_today})
            self.track_liked_and_comments()

            timer = random.randrange(10, 30)

        except Exception as e:
            print(e)

            self.status = str(e)
            self.return_status(self.status)
            timer = random.randrange(35,55)

            if "this photo has been deleted" in str(e):
                pass

            else:
                self.stop_running_bot = True

        time.sleep(random.randrange(5,8))

        for e in range(1, timer):
            sys.stdout.write(colored(f"\r[ ] liking next post in {e / timer * 100}", "green"))
            sys.stdout.flush()
            self.status = f"liking next post in {round(e / timer * 100)}%"

            self.return_status(self.status)

            if self.stop_running_bot:
                self.status = "stopping bot"
                self.return_status(self.status)
                break
            time.sleep(1)

    def like_hashtag(self,hash_):
        headers = {
            'user-agent': 'Mozilla/5.0 (iPhone; CPU iPhone OS 12_3_1 like Mac OS X) AppleWebKit/605.1.15 (KHTML, '
                          'like Gecko) Mobile/15E148 Instagram 105.0.0.11.118 (iPhone11,8; iOS 12_3_1; en_US; en-US; '
                          'scale=2.00; 828x1792; 165586599) '
        }

        post_response = self.scraper.get(f"https://i.instagram.com/api/v1/tags/web_info/?tag_name={hash_}",
                                         headers=headers)
        medias = post_response.json()['data']['recent']['sections']

        self.seen_users = []

        for section in medias:
            for media in section['layout_content']['medias']:
                # print(media['media'])
                print('')
                post_id = media['media']['pk']
                post_username=media['media']['user']['username']

                self.like_and_comment(post_id,post_username)

                if self.obtained_users_posts:
                    liked=0
                    for user in self.target_usernames:

                        if self.stop_running_bot:
                            self.status = "stopping bot"

                            self.return_status(self.status)
                            break

                        if user in self.seen_users:
                            print(colored(f"\nyou've liked {user} first 5","red"))

                        else:
                            for post in self.obtained_users_posts.get(user):

                                if self.stop_running_bot:
                                    self.status = "stopping bot"

                                    self.return_status(self.status)
                                    break

                                post_id = post
                                post_username = user
                                self.like_and_comment(post_id,post_username)

                                liked+=1

                                if liked==5:
                                    break
                            self.seen_users.append(user)

                if self.stop_running_bot:
                    self.status = "stopping bot"
                    self.return_status(self.status)
                    break

            if self.stop_running_bot:
                self.status = "stopping bot"

                self.return_status(self.status)
                break

    def fetch_gathered_data(self,hashtag=None,usernames=None,comments=None):
        print("populated fields")
        self.hashtags=hashtag
        self.target_usernames=usernames
        self.comments=comments

        random.shuffle(self.hashtags)
        random.shuffle(self.target_usernames)
        random.shuffle(self.comments)

        print("this is the comment",self.comments)

    def stop_bot(self,stop=False,logout=False):
        if stop:
            self.stop_running_bot=True

        if logout:
            self.db.remove(where("credentials") == 'true')

    def get_username_posts(self,username_):
        posts=self.scraper.get(f"https://i.instagram.com/api/v1/users/web_profile_info/?username={username_}")
        found_post=posts.json()["data"]["user"]["edge_owner_to_timeline_media"]["edges"]

        all_posts=[]
        scraped=0
        for post in found_post:

            if self.stop_running_bot:
                self.status = "stopping bot"

                self.return_status(self.status)
                break

            post_id=post["node"]["id"]

            self.status = f"getting {username_} {post_id}"
            self.return_status(self.status)

            all_posts.append(post_id)

            scraped+=1
            if scraped==random.randrange(5,10):
                break

        self.obtained_users_posts.update({username_:all_posts})

        print(self.obtained_users_posts)

    def like_passed_hashtag(self):
        liked_hashtags=0
        while True:
            for user in self.target_usernames:
                if self.stop_running_bot:
                    self.status = "stopping bot"

                    self.return_status(self.status)
                    break

                if "@" in user:
                    user=user.replace("@","")

                self.get_username_posts(user)

                timer=random.randrange(40,65)

                for request_ in range(timer):
                    self.status = f"sending next get request in {round(request_/timer*100)}"
                    self.return_status(self.status)

                    if self.stop_running_bot:
                        self.status = "stopping bot"

                        self.return_status(self.status)
                        break

                    time.sleep(1)

            for hashtag in self.hashtags:

                self.track_liked_and_comments()

                if self.stop_running_bot:
                    print("stopping bot")
                    self.status = "stopping bot"
                    self.return_status(self.status)
                    break

                if "#" in hashtag:
                    hashtag=hashtag.replace("#",'')

                self.status=f"Getting {hashtag} posts {liked_hashtags}"

                self.like_hashtag(hashtag)

                timer_=random.randrange(60,70)

                for e in range(timer_):
                    print(f"Getting next hashtag {round(e/timer_*100)}")

                    self.status = f"Getting next hashtag {round(e/timer_*100)}"
                    self.return_status(self.status)

                    if self.stop_running_bot:
                        print("stopping bot")
                        self.status = "stopping bot"
                        self.return_status(self.status)
                        break

                    time.sleep(1)

                liked_hashtags+=1

            if self.stop_running_bot:
                print("stopping bot")
                self.status="stopping bot"
                self.return_status(self.status)
                break

    def return_status(self,bot_status):
        status=self.db.search(User.status=="true")

        if status:

            self.db.update({"status":"true","current_status":bot_status})

        else:
            self.db.insert({"status":"true","current_status":bot_status})

    def update_liked(self,post_id):
        liked_before = self.db.search(User.seen_post == "true")

        if liked_before:

            seen_posts=liked_before[0].get("post_id")
            if post_id in seen_posts:
                print(f"the bot has interacted with this post before {post_id}")

                self.status = f"⚠the bot has interacted with this post before {post_id}"
                self.return_status(self.status)
                time.sleep(0.4)

                return "seen before"

            else:
                seen_posts.append(post_id)

                self.db.update({"seen_post": "true", "post_id":seen_posts})

                print(colored("updated known posts","yellow"))

                return "updated known posts"

        else:
            self.db.insert({"seen_post": "true", "post_id":[post_id]})

            print(colored("created posts db data", "yellow"))

            return "created posts db data"

    def track_liked_and_comments(self):
        if self.liked_today >= 700:
            print(colored(
                f"\n ⚠ Hey {self.username} you are approaching the maximum limit of 1000 likes per day [ {self.liked_today / self.max_likes * 100}% ] used up",
                "red"))

            self.status = f"⚠ Hey {self.username} you are approaching the maximum limit of 1000 likes per day [ {self.liked_today / self.max_likes * 100}% ] used up"
            self.return_status(self.status)
            time.sleep(0.4)

        if self.liked_today >= self.max_likes:
            print(
                colored(
                    f"\n ⛔ {self.username} you've reached the maximum limit of 1000 likes per day [ {self.liked_today / self.max_likes * 100}% ] used up",
                    "red"))

            self.status=f"⛔ {self.username} you've reached the maximum limit of 1000 likes per day [ {self.liked_today / self.max_likes * 100}% ] used up"
            self.return_status(self.status)
            time.sleep(0.4)

            remaining_timer = self.db.search(User[f"{self.username}_freeze_time"] == "true")

            if remaining_timer:
                timer_ = remaining_timer[0].get("time_stamp")
                timer_ = datetime.datetime.fromtimestamp(timer_)
                time_remaining = timer_ - datetime.datetime.now()

                sleep_mins = time_remaining.seconds
            else:
                sleep_mins = 86400
                sleep_timer_now = datetime.datetime.now() + datetime.timedelta(seconds=sleep_mins)
                self.db.insert({f"{self.username}_freeze_time": "true", "time_stamp": sleep_timer_now.timestamp()})

            self.sleep_bot(timer=sleep_mins, reason="[ max liked posts reached ] sleep mode ")
            self.db.update({f"{self.username}_freeze_time": "false", "time_stamp": 0})

        if self.comment_today >= 100:
            print(colored(
                f"\n ⚠ Hey {self.username} you are approaching the maximum limit of 200 comments per day [ {self.comment_today / self.max_comments * 100} ] used up",
                "blue"))

            self.status = f" ⚠ Hey {self.username} you are approaching the maximum limit of 200 comments per day [ {self.comment_today / self.max_comments * 100} ] used up"
            self.return_status(self.status)
            time.sleep(0.4)

        if self.comment_today >= self.max_comments:
            print(
                colored(
                    f"\n ⛔ {self.username} you've reached the maximum limit of 200 comments per day [ {self.comment_today / self.max_comments * 100}% ] used up",
                    "red"))

            self.status=f"⛔ {self.username} you've reached the maximum limit of 200 comments per day [ {self.comment_today / self.max_comments * 100}% ] used up"

            self.return_status(self.status)
            self.comments.clear()
            time.sleep(0.4)

            '''disable comments'''

    def sleep_bot(self, timer=random.randrange(850, 1220), reason=""):
        sleep_time = timer
        lengths = [e for e in range(0, 10)]
        timer = time.perf_counter()
        char = "▓"
        for e in range(sleep_time):
            percentage = e / sleep_time * 100
            current_time = time.perf_counter() - timer
            time_remaining = datetime.timedelta(seconds=sleep_time - current_time)
            if "max liked posts" in reason:
                sleep_mins = "Remaining Time" + str(time_remaining)
                time_remaining = ""
            else:
                sleep_mins = str(time_remaining).split(":")[1] + " mins"
                time_remaining = ""
            sys.stdout.write(
                colored(
                    f"\r[{sleep_mins}] {reason} sleep Timeout started | progress {time_remaining}{char} {round(percentage, 4)}%",
                    "green"))

            self.status = f"[{sleep_mins}] {reason} sleep Timeout started | progress {time_remaining}{char} {round(percentage, 4)}%"

            self.return_status(self.status)

            sys.stdout.flush()
            char_concatenate = round(percentage / 10) + 1

            char = "▓" * char_concatenate
            if len(char) in lengths:
                print("")
                lengths.remove(len(char))
            time.sleep(1)

            if self.stop_running_bot:
                self.status = "stopping bot"
                self.return_status(self.status)
                break




import datetime
import sys
import threading
import time

import requests

# GUI FILE
# IMPORT FUNCTIONS

from PyQt5.QtWidgets import QApplication,QMainWindow
from PyQt5 import QtCore
from .ui_main import Ui_MainWindow
from PyQt5.QtCore import *
import os
import pickle
from cryptography import fernet

import pymongo
from .backend_code import *

from tinydb import TinyDB, Query
db = TinyDB('database.json')

db2 = TinyDB('last_data_database.json')
User = Query()

start_login=True
win_set=False
can_login=False
successful_login = False
break_login_thread=False
found_images=False
profile_set=False
bot_running = False

avatar=''.encode()
followers=""
following=""

lost_followers_=0
added_followers_=0

login_fail=""

error_msg=""

last_status=""

recent_follower_stat="gained"

try:
    password = "RU2h08woBk4qlTHs"
    client = pymongo.MongoClient(
        f"mongodb+srv://natalie:{password}@cluster0.pzbl6.mongodb.net/?retryWrites=true&w=majority")
    mongo_db = client.get_database("natalie_app")

except Exception as e:
    error_msg="check your internet connection \n DB connection refused"

cookie_creds=[]

cloud_images={}


hashtags=[]
comments=[]
target_usernames=[]

status=""

known_status=[]

encryption_key = b'tUvzG-BWuh2xQB1k4VKynl4ox_2k9VHCMjRe4-UOQgA='


GLOBAL_STATE=0
max_likes=50
liked=0

loaded_img=False
from PyQt5 import QtCore
from PyQt5.QtGui import QColor
from PyQt5.QtWidgets import QWidget, QHBoxLayout, \
    QGraphicsDropShadowEffect, QPushButton, QApplication, QComboBox,QSizeGrip
from PyQt5 import QtCore, QtGui, QtWidgets
import cv2

from PyQt5.QtWidgets import *
from PyQt5 import QtCore, QtGui
from PyQt5.QtGui import *
from PyQt5.QtCore import *
import pymongo
import threading

scroll_style_sheet=''' QScrollBar:vertical {
	border: none;
    background: rgb(45, 45, 68);
    width: 14px;
    margin: 15px 0 15px 0;
	border-radius: 0px;
 }

/*  HANDLE BAR VERTICAL */
QScrollBar::handle:vertical {	
	background-color: rgb(80, 80, 122);
	min-height: 30px;
	border-radius: 7px;
}
QScrollBar::handle:vertical:hover{	
	background-color: rgb(255, 0, 127);
}
QScrollBar::handle:vertical:pressed {	
	background-color: rgb(185, 0, 92);
}

/* BTN TOP - SCROLLBAR */
QScrollBar::sub-line:vertical {
	border: none;
	background-color: rgb(59, 59, 90);
	height: 15px;
	border-top-left-radius: 7px;
	border-top-right-radius: 7px;
	subcontrol-position: top;
	subcontrol-origin: margin;
}
QScrollBar::sub-line:vertical:hover {	
	background-color: rgb(255, 0, 127);
}
QScrollBar::sub-line:vertical:pressed {	
	background-color: rgb(185, 0, 92);
}

/* BTN BOTTOM - SCROLLBAR */
QScrollBar::add-line:vertical {
	border: none;
	background-color: rgb(59, 59, 90);
	height: 15px;
	border-bottom-left-radius: 7px;
	border-bottom-right-radius: 7px;
	subcontrol-position: bottom;
	subcontrol-origin: margin;
}
QScrollBar::add-line:vertical:hover {	
	background-color: rgb(255, 0, 127);
}
QScrollBar::add-line:vertical:pressed {	
	background-color: rgb(185, 0, 92);
}

/* RESET ARROW */
QScrollBar::up-arrow:vertical, QScrollBar::down-arrow:vertical {
	background: none;
}
QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical {
	background: none;
}


'''


class MainWindow(QMainWindow):
    load_animation=""

    username = ""
    password = ""

    def moveWindow(self,event):
        # RESTORE BEFORE MOVE

        if UIFunctions.returnStatus() == 1:
            UIFunctions.maximize_restore(self)

        # IF LEFT CLICK MOVE WINDOW

        if event.buttons() == QtCore.Qt.LeftButton:
            self.move(self.pos() + event.globalPos() - self.dragPos)
            self.dragPos = event.globalPos()
            event.accept()

    def get_part_of_day(self,h):
        return (
            "Good morning"
            if 5 <= h <= 11
            else "Good afternoon"
            if 12 <= h <= 16
            else "Good evening"
            if 17 <= h <= 23
            else "Nighty Night"
        )

    def initialize_win(self):
        QMainWindow.__init__(self)
        self.ui = Ui_MainWindow()
        self.ui.setupUi(self)

        self.ui.status_listwidget.clear()

        self.ui.liked_progressBar.setValue(0)
        self.ui.like_listWidget.clear()

        self.ui.comments_progressbar.setValue(0)
        self.ui.comment_listwidget.clear()

        self.get_last_passed_data()

        # MOVE WINDOW


        # SET TITLE BAR
        self.ui.header_frame.mouseMoveEvent = self.moveWindow

        self.ui.login_header_frame.mouseMoveEvent=self.moveWindow

        UIFunctions.uiDefinitions(self)

        UIFunctions.edit_verical_scrollbar(self)

        UIFunctions.change_avatar(self)

        self.update_worker = UpdateScreen()
        self.update_worker.start()
        self.update_worker.signal.connect(self.update_)

        self.images_worker = TrackImages()
        self.images_worker.start()
        self.images_worker.signal.connect(self.get_images)

        self.followers_worker = TrackFollowers()
        self.followers_worker.start()
        self.followers_worker.signal.connect(self.track_profile_updator)

        self.collected_inputs_worker = Collect_targetusers_hashtags_comments()
        self.collected_inputs_worker.start()
        self.collected_inputs_worker.signal.connect(self.collected_hashtags_and_data)

        self.setWindowTitle("Natalie App")

        th=threading.Thread(target=self.get_creds_thread)
        th.start()

        UIFunctions.set_current_win(self,0)
        UIFunctions.loading_page(self)

        self.ui.pushButton.clicked.connect(self.login_button)

        self.ui.start_button.clicked.connect(self.start_bot)

        self.ui.logout_button.clicked.connect(self.logout)

        self.show()

    def get_last_passed_data(self):
        last_data=db2.search(User.run_data=="yes")
        if last_data:
            last_comment=last_data[0].get("comments")
            last_target_users=last_data[0].get("target_users")
            last_hashtags=last_data[0].get("last_hashtags")

            for hashtag in last_hashtags:
                self.ui.hashtag_input.insertPlainText(f"{hashtag}\n")

            for user in last_target_users:
                self.ui.targetusernames_input.insertPlainText(f"{user}\n")

            for comment in last_comment:
                self.ui.add_comments_input.insertPlainText(f"{comment}\n")

        else:
            pass

    def logout(self):
        global bot_running
        print("logging out")

        if not bot_running:
            self.pop_up_window("you must start the bot and click logout inorder to logout !")

        else:
            self.bot_.stop_bot(stop=True,logout=True)

            UIFunctions.add_scroll_status(self,f"logged out of {self.username} ")

            bot_running=False

            self.pop_up_window("you'll be logged out")

            self.close()

            UIFunctions.set_current_win(self,1)
            UIFunctions.login_page(self)

    def populate_status_(self):
        global status
        while True:
            if bot_running:
                try:
                    status_ = db.search(User.status == "true")

                    if status_:
                        status=status_[0].get("current_status")

                except Exception as e:
                    print(e)

            else:
                db.update({"status": "true", "current_status":f"last run {str(time.ctime())}"})
                break

            time.sleep(0.1)

    def run_main_bot(self,hashtags_,target_usernames_,comments_):
        print("bot is running")

        last_data = db2.search(User.run_data == "yes")

        while "" in comments_:
            comments_.remove("")

        while "" in target_usernames_:
            target_usernames_.remove("")

        while "" in hashtags_:
            hashtags_.remove("")

        print(comments_)
        print(target_usernames_)
        print(hashtags_)

        if last_data:

            db2.update({"run_data":"yes","comments":comments_,"target_users":target_usernames_,"last_hashtags":hashtags_})

        else:
            db2.insert({"run_data": "yes", "comments": comments_, "target_users":target_usernames_,
                       "last_hashtags":hashtags_})

        self.bot_ = MainBot()
        self.bot_.login_user(self.username,self.password,db)
        self.bot_.fetch_gathered_data(hashtags_,target_usernames_,comments_)

        self.bot_.like_passed_hashtag()

    def start_bot(self):
        global bot_running

        if bot_running and self.ui.start_button.text()=="Stop bot":
            print("bot is already running ,stopping the bot")
            self.pop_up_window("you are about to stop the bot")
            self.bot_.stop_bot(stop=True)

            bot_running=False

            self.ui.start_button.setText("Start Bot")

        else:

            found_hashtags=False
            found_users=False

            for hash_ in hashtags:
                if hash_:
                    found_hashtags=True

            for user in target_usernames:
                if user:
                    found_users=True

            if not found_hashtags and not found_users:
                self.pop_up_window("the bot can't run without hashtags or comments!\nspecify some hashtags or target usernames")

            elif found_users and not found_hashtags:
                self.pop_up_window("the bot can't run on target usernames alone \nspecify atleast one hashtag")
                # main_bot_thread=threading.Thread(target=self.run_main_bot,args=(hashtags,target_usernames,comments))
                # main_bot_thread.start()
                #
                # bot_running = True
                #
                # populate_status = threading.Thread(target=self.populate_status_)
                # populate_status.start()
                #
                # self.ui.start_button.setText("Stop bot")

            elif found_hashtags and not found_users:
                self.pop_up_window("the bot will run on hashtags only")

                main_bot_thread = threading.Thread(target=self.run_main_bot, args=(hashtags, target_usernames, comments))
                main_bot_thread.start()

                bot_running = True

                populate_status=threading.Thread(target=self.populate_status_)
                populate_status.start()

                self.ui.start_button.setText("Stop bot")

            elif found_hashtags and found_users:
                self.pop_up_window("the bot will run on both hashtags and target usernames")

                main_bot_thread = threading.Thread(target=self.run_main_bot, args=(hashtags, target_usernames, comments))
                main_bot_thread.start()

                bot_running = True

                populate_status = threading.Thread(target=self.populate_status_)
                populate_status.start()

                self.ui.start_button.setText("Stop bot")

    def collected_hashtags_and_data(self,val):

        global hashtags,comments,target_usernames

        hashtags_inputs=self.ui.hashtag_input.toPlainText().split("\n")
        target_users_inputs=self.ui.targetusernames_input.toPlainText().split("\n")
        comment_inputs=self.ui.add_comments_input.toPlainText().split("\n")

        hashtags=hashtags_inputs
        comments=comment_inputs
        target_usernames=target_users_inputs

        print(hashtags)
        print(comments)
        print(target_usernames)

    def track_profile_updator(self,val):
        global profile_set,status,last_status
        print(val)

        if avatar and not profile_set:

            qp = QtGui.QPixmap()
            qp.loadFromData(avatar)

            self.ui.user_avatar.setPixmap(qp)
            hour_=int(datetime.datetime.now().hour)

            self.ui.username.setText(f"{self.get_part_of_day(hour_)}\n{self.username}")

            #profile_set=True

        new_status = f"you'll be logged in as {self.username} once you click Start Bot !"

        if new_status not in known_status and self.username:
            UIFunctions.add_scroll_status(self,new_status)
            known_status.append(new_status)

        if status and self.username and status !=last_status:
            UIFunctions.add_scroll_status(self, status)
            last_status=status

        if recent_follower_stat=="gained":
            qp = QtGui.QPixmap()
            qp.loadFromData(cloud_images.get("increased"))

            self.ui.stat_indicator.setPixmap(qp)

            self.ui.gaiin_lost.setText(f"{added_followers_} Gained since startup")

        else:
            qp = QtGui.QPixmap()
            qp.loadFromData(cloud_images.get("decreased"))

            self.ui.stat_indicator.setPixmap(qp)

            self.ui.gaiin_lost.setText(f"{lost_followers_} lost since startup")

        print(f"found followers {followers}")
        print(f"fount following {following}")

        self.ui.follower_count.setText(f"{followers}")
        self.ui.following_count.setText(f"{following}")

    def live_follower_and_avatar(self):
        start = time.perf_counter()

        def get_followers(user):
            global lost_followers_,added_followers_,avatar,followers,following,recent_follower_stat
            try:
                lost_followers = 0
                gained_followers = 0
                headers = {
                    'User-Agent': 'Mozilla/5.0 (iPhone14,3; U; CPU iPhone OS 15_0 like Mac OS X) AppleWebKit/602.1.50 (KHTML, like Gecko) Version/10.0 Mobile/19A346 Safari/602.1'

                }

                r = requests.get(f"https://instastories.watch/api/profile?username={user}", headers=headers)
                resp = r.json()

                followers = resp["profileInfo"]["subscriber"]
                following = resp["profileInfo"]["subscription"]
                avatar_url = resp["profileInfo"]["avatar"].split("/proxy/")[1]

                r = requests.get(avatar_url, headers=headers)
                avatar = r.content

                print(avatar_url)

                found_user_data = db.search(User.user == f'{user}')
                if not found_user_data:

                    db.insert({"user": f"{user}", "followers": f'{followers}', "following": f"{following}"})

                    added_followers = 0

                    print('first data loaded')

                else:
                    difference = int(found_user_data[0].get('followers')) - int(followers) + lost_followers

                    added_followers = int(followers) - int(found_user_data[0].get('followers'))

                    if difference >= 1:
                        lost_followers += difference

                        lost_followers_=lost_followers

                        db.update({"user": f"{user}", "followers": f'{followers}', "following": f"{following}",
                                   "lost_followers": lost_followers, "gained_followers": added_followers})

                        recent_follower_stat = "lost"

                    if added_followers > 0:
                        gained_followers += added_followers

                        added_followers_=gained_followers

                        db.update({"user": f"{user}", "followers": f'{followers}', "following": f"{following}",
                                   "lost_followers": lost_followers, "gained_followers": gained_followers})

                        recent_follower_stat="gained"

                print(
                    f"[ time frame ] {datetime.timedelta(seconds=time.perf_counter() - start)}\n[ ] followers {followers} \n[ ] following {following} \n[ ] gained {added_followers} \n[ ] lost {lost_followers}",
                    end="\n\n")

            except Exception as e:
                print(e)

        while True:
            get_followers(user=self.username)
            time.sleep(random.randrange(60,140))

    def get_images(self,val):
        global found_images
        print(val)
        if cloud_images:
            qp = QtGui.QPixmap()
            qp.loadFromData(cloud_images.get("loading_screen_img"))
            self.ui.loading_image.setPixmap(qp)
            print("set loading  screen image")

            qp = QtGui.QPixmap()
            qp.loadFromData(cloud_images.get("login_screen_img"))

            self.ui.image_background.setPixmap(qp)

            qp = QtGui.QPixmap()
            qp.loadFromData(cloud_images.get("increased"))

            self.ui.stat_indicator.setPixmap(qp)

            "loading_image"

            print("set login screen image")

            found_images=True

    def get_creds_thread(self):
        global successful_login
        # simulate some heavy lifting

        #time.sleep(7)

        credential_cookies = mongo_db.get_collection("images")
        images = credential_cookies.find()

        for image in images:

            for key,value in image.items():
                if key !="_id":
                    print(key)
                    cloud_images.update(image)

        time.sleep(7)

        '''wait for thread to add background images'''

        encrypt_creds = fernet.Fernet(encryption_key)

        credentials = db.search(User.credentials == 'true')

        if credentials:
            # print(credentials)
            decrypt_credentials = credentials[0].get("encrypted").encode()

            decrypt_cryptography = encrypt_creds.decrypt(decrypt_credentials)
            decrypt_pickle2 = pickle.loads(decrypt_cryptography)
            self.username = decrypt_pickle2.get("username", "specify a username")
            self.password = decrypt_pickle2.get("password", "specify a password")

            cookie_creds.append(self.username)
            cookie_creds.append(self.password)
            successful_login=True

            print(f"found credentials")

        else:
            cookie_creds.append("no cookies found")
            print("no cookies found")

    def pop_up_window(self,message):
        msg = QMessageBox()
        msg.setStyleSheet(
                "background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(68, 68, 68, 255), stop:1 rgba(52, 52, 52, 255));\n"
                "\n"
                "border-radius:2px;\ncolor:white;")

        msg.setWindowFlag(QtCore.Qt.FramelessWindowHint)
        msg.setWindowTitle("Natalie App")

        msg.setIcon(QMessageBox.Information)

        if "logged out" in message:

            msg.setText(f"{message} in 10s")

        else:
            msg.setText(message)

        msg.exec_()

    def login_button(self):

        global can_login,successful_login, break_login_thread, login_fail, error_msg
        if not can_login:

            login_fail = ""

            error_msg = ""

            break_login_thread = False
            login_fail = False

            print("login button clicked")
            username=self.ui.username_input.text()
            password=self.ui.password_input.text()

            self.username=username
            self.password=password

            print(username)
            # print(password)

            if not username:
                self.pop_up_window("you've not entered a username")

            if not password:
                self.pop_up_window("you've not entered a password")

            if password and username:
                can_login=True

                self.ui.pushButton.setStyleSheet("*{\n"
                                                 "background-color: rgb(106, 59, 248);\n"
                                                 "color: rgb(234, 234, 234);\n"
                                                 "}\n"
                                                 "\n")
                self.ui.pushButton.setText("Login you in ")

                self.login_worker = ListenLogin()
                self.login_worker.start()
                self.login_worker.signal.connect(self.login_status)

                login_thread=threading.Thread(target=self.populate_cookies_field,args=(username,password))
                login_thread.start()

        else:
            self.ui.pushButton.setStyleSheet("*{\n"
"background-color: rgb(106, 59, 248);\n"
"color: rgb(234, 234, 234);\n"
"}\n"
"\n")
            self.ui.pushButton.setText("Chill broski \n still login in .. ")
            print("there's is a login going on")

    def login_status(self,val):
        global break_login_thread
        print(val)
        if login_fail:

            self.ui.pushButton.setStyleSheet("*{\n"
                                             "background-color: rgb(255, 23, 96);\n"
                                             "color: rgb(234, 234, 234);\n"
                                             "}\n"
                                             "\n"
                                             "*:hover{\n"
                                             "    background-color: rgb(106, 59, 248);\n"
                                             "}")

            self.ui.pushButton.setText("Login")

            break_login_thread = True
            self.pop_up_window(login_fail)

        elif successful_login:
            break_login_thread = True

            UIFunctions.set_current_win(self, 2)
            UIFunctions.main_page(self)
            print("login succeeded")

            self.ui.username.setText(self.username)

            tracking_func = threading.Thread(target=self.live_follower_and_avatar)
            tracking_func.start()

    def populate_cookies_field(self,username,password):
        global successful_login,login_fail,can_login

        while True:
            if can_login:
                bot_=MainBot()
                returned_msg= bot_.login_user(username,password,db)
                if "login failed" not in returned_msg:
                    successful_login=True
                    print("populated cookies")
                    print(returned_msg)
                else:
                    login_fail=returned_msg

                can_login=False

            break

    def update_(self,val):
        global win_set
        progress=round(int(val)/100*100)
        print(val)

        if cookie_creds:

            if "no cookies found" in cookie_creds:
                UIFunctions.set_current_win(self,1)
                UIFunctions.login_page(self)

            elif cookie_creds or successful_login:
                UIFunctions.set_current_win(self, 2)
                UIFunctions.main_page(self)

                self.ui.username.setText(self.username)

                tracking_func=threading.Thread(target=self.live_follower_and_avatar)
                tracking_func.start()

            win_set=True

        self.load_animation+="."

        if len(self.load_animation)>=5:
            self.load_animation=""

        '''check connections'''
        if error_msg:
            self.ui.connection_label.setText(error_msg)

        else:
            self.ui.connection_label.setText(f"Connecting to database {self.load_animation}")
            self.ui.loading_bar.setValue(progress)

    def mousePressEvent(self, event):
        self.dragPos = event.globalPos()


class UpdateScreen(QThread):
    signal = pyqtSignal(str)

    def run(self):
        counter=0
        while True:
            self.signal.emit(f"{counter}")
            time.sleep(0.2)
            counter+=1
            if win_set:
                break


class ListenLogin(QThread):
    signal = pyqtSignal(str)

    def run(self):
        counter=0
        while True:
            self.signal.emit(f"listening for login{counter}")
            time.sleep(0.2)
            counter+=1
            if break_login_thread:
                print("block login thread")
                break

            else:
                print("dont block login")


class TrackImages(QThread):
    signal = pyqtSignal(str)

    def run(self):
        counter = 0
        while True:
            self.signal.emit(f"Waiting for images{counter}")
            time.sleep(0.2)
            counter += 1
            if found_images:
                print("block login thread")
                break


class TrackFollowers(QThread):
    signal = pyqtSignal(str)

    def run(self):
        counter = 0
        while True:
            self.signal.emit(f"Tracking followers,following,profile avatar update{counter}")
            time.sleep(0.3)
            counter += 1


class Collect_targetusers_hashtags_comments(QThread):
    signal = pyqtSignal(str)

    def run(self):
        counter = 0
        while True:
            self.signal.emit(f"collecting inputs {counter}")
            time.sleep(0.4)
            counter += 1


class UIFunctions(MainWindow):
    ## ==> MAXIMIZE RESTORE FUNCTION

    def maximize_restore(self):
        global GLOBAL_STATE

        status = GLOBAL_STATE

        self.ui.close_button.setToolTip("close")
        self.ui.close_button_4.setToolTip("close")

        # IF NOT MAXIMIZED
        if status == 0:
            self.showMaximized()

            # SET GLOBAL TO 1
            GLOBAL_STATE = 1

            # IF MAXIMIZED REMOVE MARGINS AND BORDER RADIUS
            # self.ui.main_frame.setContentsMargins(0, 0, 0, 0)
            # self.ui.main_frame.setStyleSheet("background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(42, 44, 111, 255), stop:0.521368 rgba(28, 29, 73, 255)); border-radius: 0px;")
            self.ui.restore_button.setToolTip("Restore")

        else:
            GLOBAL_STATE = 0
            self.showNormal()
            self.resize(self.width()+1, self.height()+1)
            # self.ui.main_frame.setContentsMargins(10, 10, 10, 10)
            # self.ui.main_frame.setStyleSheet("background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(42, 44, 111, 255), stop:0.521368 rgba(28, 29, 73, 255)); border-radius: 10px;")

            self.ui.minimize_button.setToolTip("minimize")

            self.ui.minimize_button_4.setToolTip("minimize")

    ## ==> UI DEFINITIONS
    def uiDefinitions(self):

        # REMOVE TITLE BAR
        self.setWindowFlag(QtCore.Qt.FramelessWindowHint)
        self.setAttribute(QtCore.Qt.WA_TranslucentBackground)

        # SET DROPSHADOW WINDOW
        self.shadow = QGraphicsDropShadowEffect(self)
        self.shadow.setBlurRadius(20)
        self.shadow.setXOffset(0)
        self.shadow.setYOffset(0)
        self.shadow.setColor(QColor(0, 0, 0, 100))

        # APPLY DROPSHADOW TO FRAME
        self.ui.main_frame.setGraphicsEffect(self.shadow)

        self.ui.login_header_frame.setGraphicsEffect(self.shadow)

        # # MAXIMIZE / RESTORE
        self.ui.restore_button.clicked.connect(lambda: UIFunctions.maximize_restore(self))
        #
        # # MINIMIZE
        self.ui.minimize_button.clicked.connect(lambda: self.showMinimized())
        #
        # # CLOSE
        self.ui.close_button.clicked.connect(lambda: self.close())

        '''login page'''

        # # MAXIMIZE / RESTORE
        # self.ui.restore_button_4.clicked.connect(lambda: UIFunctions.maximize_restore(self))
        #
        # # MINIMIZE
        self.ui.minimize_button_4.clicked.connect(lambda: self.showMinimized())
        #
        # # CLOSE
        self.ui.close_button_4.clicked.connect(lambda: self.close())

        # ==> CREATE SIZE GRIP TO RESIZE WINDOW
        self.sizegrip = QSizeGrip(self.ui.footer_frame)
        self.sizegrip.setStyleSheet("QSizeGrip { width: 10px; height: 10px; margin: 5px } QSizeGrip:hover { background-color: rgb(50, 42, 94) }")
        self.sizegrip.setToolTip("Resize Window")

    def change_avatar(self):

        self.ui.user_avatar.setStyleSheet('''*{border:2px solid  rgb(17, 120, 255);}\n
                                            *:hover{border:3px solid rgb(255, 23, 96);}''')

    def loading_page(self):
        self.setStyleSheet("\n"
"background-color: rgba(59, 59, 59,0);\n"
"border-radius:5px;")

        self.resize(670, 331)

        self.ui.loading_image.setGeometry(QtCore.QRect(30,10, 651, 331))

        self.ui.loading_bar.setGeometry(QtCore.QRect(180,150, 343, 24))

        self.ui.connection_label.setGeometry(QtCore.QRect(240,240, 241, 61))

    def set_current_win(self,win):
        self.ui.stackedWidget.setCurrentIndex(win)

    def login_page(self):
        self.move(500,100)

        self.setStyleSheet("\n"
                           "background-color: rgba(59, 59, 59,0);\n"
                           "border-radius:5px;")

        self.ui.login_header_frame.setStyleSheet("\n"
                           "background-color: rgba(59, 59, 59,255);\n"
                           "border-radius:5px;")

        self.resize(451,737)

        self.ui.login_body_frame.setMaximumSize(QtCore.QSize(451,737))

    def main_page(self):
        self.move(500, 100)

        self.ui.hashtag_title.setStyleSheet("border:none;")
        self.ui.commented_title_2.setStyleSheet("border:none;")

        self.setStyleSheet("\n"
                           "background-color: rgba(59, 59, 59,35);\n"
                           "border-radius:5px;")

        self.ui.header_frame.setStyleSheet("\n"
                                           "background-color: rgba(59, 59, 59,255);\n"
                                           "border-radius:5px;")

        self.resize(542,614)
        self.setMaximumSize(QtCore.QSize(16777215, 16777215))

    def set_blur(self):
        self.blur_effect = QGraphicsBlurEffect()

        # setting blur radius
        self.blur_effect.setBlurRadius(4)

        self.ui.hashtag_frame.setGraphicsEffect(self.blur_effect)

    def edit_verical_scrollbar(self):

        scroll_bar = QScrollBar(self)

        # setting style sheet to the scroll bar
        scroll_bar.setStyleSheet(scroll_style_sheet)

        # setting vertical scroll bar to it
        self.ui.hashtag_input.setVerticalScrollBar(scroll_bar)

        scroll_bar = QScrollBar(self)

        # setting style sheet to the scroll bar
        scroll_bar.setStyleSheet(scroll_style_sheet)

        self.ui.add_comments_input.setVerticalScrollBar(scroll_bar)

        scroll_bar = QScrollBar(self)

        # setting style sheet to the scroll bar
        scroll_bar.setStyleSheet(scroll_style_sheet)

        self.ui.targetusernames_input.setVerticalScrollBar(scroll_bar)

        scroll_bar = QScrollBar(self)

        # setting style sheet to the scroll bar
        scroll_bar.setStyleSheet(scroll_style_sheet)

        self.ui.like_listWidget.setVerticalScrollBar(scroll_bar)

        scroll_bar = QScrollBar(self)

        # setting style sheet to the scroll bar
        scroll_bar.setStyleSheet(scroll_style_sheet)

        self.ui.comment_listwidget.setVerticalScrollBar(scroll_bar)

        scroll_bar = QScrollBar(self)

        # setting style sheet to the scroll bar
        scroll_bar.setStyleSheet(scroll_style_sheet)

        self.ui.status_listwidget.setVerticalScrollBar(scroll_bar)

    def add_scroll_status(self,value):

        print('''      .'\   /`.
         .'.-.`-'.-.`.
    ..._:   .-. .-.   :_...
  .'    '-.(o ) (o ).-'    `.
 :  _    _ _`~(_)~`_ _    _  :
:  /:   ' .-=_   _=-. `   ;\  :
:   :|-.._  '     `  _..-|:   :
 :   `:| |`:-:-.-:-:'| |:'   :
  `.   `.| | | | | | |.'   .'
    `.   `-:_| | |_:-'   .'
 jgs  `-._   ````    _.-'
          ``-------''''')

        self.ui.status_listwidget.setStyleSheet("color: rgb(0,170,255)")
        self.ui.status_listwidget.addItem(value)
        self.ui.status_listwidget.scrollToBottom()

        if "successfully liked" in value:
            print(f"found liking in value {value}")
            value=value.split("|")
            bar_val=int(value[1])

            self.ui.liked_progressBar.setValue(bar_val)

            self.ui.like_listWidget.addItem(value[0])
            self.ui.like_listWidget.scrollToBottom()

        if "maximum limit of 1000 likes" in value:
            bar_val=round(float(value.split("[")[1].split("]")[0].replace("%","")))

            self.ui.liked_progressBar.setValue(bar_val)

            self.ui.like_listWidget.addItem(value)
            self.ui.like_listWidget.scrollToBottom()

        if "like function" in value:
            value=value.split("sleep")[0]

            self.ui.like_listWidget.addItem(value)
            self.ui.like_listWidget.scrollToBottom()

        if "successfully commented" in value:
            value =value.split("|")
            bar_val=int(value[1])
            self.ui.comments_progressbar.setValue(bar_val)

            self.ui.comment_listwidget.addItem(value[0])

            self.ui.comment_listwidget.scrollToBottom()

        if "maximum limit of 200 comments" in value:
            bar_val = round(float(value.split("[")[1].split("]")[0].replace("%", "")))

            self.ui.comments_progressbar.setValue(bar_val)

            self.ui.comment_listwidget.addItem(value)

            self.ui.comment_listwidget.scrollToBottom()

    ## RETURN STATUS IF WINDOWS IS MAXIMIZE OR RESTAURED
    def returnStatus():
        return GLOBAL_STATE


def start():
    app = QApplication(sys.argv)
    m=MainWindow()
    m.initialize_win()

    os._exit(app.exec_())

    m.update()






# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'nat_ui.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
#         MainWindow.resize(839, 737)
#         MainWindow.setMaximumSize(QtCore.QSize(16777215, 16777215))
#         MainWindow.setStyleSheet("\n"
# "background-color: rgb(59, 59, 59);\n"
# "border-radius:5px;")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_43 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_43.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_43.setSpacing(3)
        self.verticalLayout_43.setObjectName("verticalLayout_43")
        self.stackedWidget = QtWidgets.QStackedWidget(self.centralwidget)
        self.stackedWidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.stackedWidget.setObjectName("stackedWidget")
        self.loading_page = QtWidgets.QWidget()
        self.loading_page.setObjectName("loading_page")
        self.verticalLayout_47 = QtWidgets.QVBoxLayout(self.loading_page)
        self.verticalLayout_47.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_47.setObjectName("verticalLayout_47")
        self.loading_frame = QtWidgets.QFrame(self.loading_page)
        self.loading_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.loading_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.loading_frame.setObjectName("loading_frame")
        self.loading_image = QtWidgets.QLabel(self.loading_frame)
        self.loading_image.setGeometry(QtCore.QRect(30, 170, 651, 331))
        self.loading_image.setText("")
        self.loading_image.setPixmap(QtGui.QPixmap("../../Downloads/lerone.jpg"))
        self.loading_image.setScaledContents(True)
        self.loading_image.setObjectName("loading_image")
        self.connection_label = QtWidgets.QLabel(self.loading_frame)
        self.connection_label.setGeometry(QtCore.QRect(240, 410, 241, 61))
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(11)
        self.connection_label.setFont(font)
        self.connection_label.setStyleSheet("color: rgb(166, 166, 166);\n"
"background-color: rgba(59, 59, 59,50);")
        self.connection_label.setAlignment(QtCore.Qt.AlignCenter)
        self.connection_label.setObjectName("connection_label")
        self.loading_bar = QtWidgets.QProgressBar(self.loading_frame)
        self.loading_bar.setGeometry(QtCore.QRect(180, 320, 343, 24))
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.loading_bar.setFont(font)
        self.loading_bar.setStyleSheet("QProgressBar {\n"
"     border: none;\n"
"     color:white;\n"
"     background-color: rgba(79, 79, 79,70);\n"
" }\n"
"\n"
" QProgressBar::chunk {\n"
"     \n"
"    background-color: rgb(255, 65, 109);\n"
"     width: 20px;\n"
" }\n"
"\n"
"\n"
"")
        self.loading_bar.setProperty("value", 24)
        self.loading_bar.setAlignment(QtCore.Qt.AlignCenter)
        self.loading_bar.setObjectName("loading_bar")
        self.verticalLayout_47.addWidget(self.loading_frame)
        self.stackedWidget.addWidget(self.loading_page)
        self.login_page = QtWidgets.QWidget()
        self.login_page.setObjectName("login_page")
        self.login_header_frame = QtWidgets.QFrame(self.login_page)
        self.login_header_frame.setGeometry(QtCore.QRect(0, 0, 448, 24))
        self.login_header_frame.setMaximumSize(QtCore.QSize(16777215, 30))
        self.login_header_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.login_header_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.login_header_frame.setObjectName("login_header_frame")
        self.horizontalLayout_24 = QtWidgets.QHBoxLayout(self.login_header_frame)
        self.horizontalLayout_24.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_24.setObjectName("horizontalLayout_24")
        self.left_header_content_4 = QtWidgets.QFrame(self.login_header_frame)
        self.left_header_content_4.setStyleSheet("background-color:none;")
        self.left_header_content_4.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.left_header_content_4.setFrameShadow(QtWidgets.QFrame.Raised)
        self.left_header_content_4.setObjectName("left_header_content_4")
        self.verticalLayout_44 = QtWidgets.QVBoxLayout(self.left_header_content_4)
        self.verticalLayout_44.setContentsMargins(9, 0, 0, 0)
        self.verticalLayout_44.setSpacing(3)
        self.verticalLayout_44.setObjectName("verticalLayout_44")
        self.label_4 = QtWidgets.QLabel(self.left_header_content_4)
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(13)
        font.setBold(False)
        font.setWeight(50)
        self.label_4.setFont(font)
        self.label_4.setStyleSheet("color: rgb(255, 23, 96);")
        self.label_4.setObjectName("label_4")
        self.verticalLayout_44.addWidget(self.label_4)
        self.horizontalLayout_24.addWidget(self.left_header_content_4)
        self.header_buttons_4 = QtWidgets.QFrame(self.login_header_frame)
        self.header_buttons_4.setMinimumSize(QtCore.QSize(15, 15))
        self.header_buttons_4.setMaximumSize(QtCore.QSize(400, 16777215))
        self.header_buttons_4.setStyleSheet("background-color:none;")
        self.header_buttons_4.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.header_buttons_4.setFrameShadow(QtWidgets.QFrame.Raised)
        self.header_buttons_4.setObjectName("header_buttons_4")
        self.horizontalLayout_23 = QtWidgets.QHBoxLayout(self.header_buttons_4)
        self.horizontalLayout_23.setContentsMargins(300, 0, 0, 0)
        self.horizontalLayout_23.setSpacing(3)
        self.horizontalLayout_23.setObjectName("horizontalLayout_23")
        self.close_button_4 = QtWidgets.QPushButton(self.header_buttons_4)
        self.close_button_4.setMinimumSize(QtCore.QSize(15, 15))
        self.close_button_4.setMaximumSize(QtCore.QSize(16, 16))
        self.close_button_4.setStyleSheet("*{\n"
"border-none;\n"
"border-radius:8px;\n"
"background-color:red;\n"
"\n"
"\n"
"}")
        self.close_button_4.setText("")
        self.close_button_4.setObjectName("close_button_4")
        self.horizontalLayout_23.addWidget(self.close_button_4)
        self.restore_button_4 = QtWidgets.QPushButton(self.header_buttons_4)
        self.restore_button_4.setMinimumSize(QtCore.QSize(15, 15))
        self.restore_button_4.setMaximumSize(QtCore.QSize(16, 16))
        self.restore_button_4.setStyleSheet("*{\n"
"border-radius:8px;\n"
"\n"
"background-color: rgb(255, 142, 29);\n"
"\n"
"\n"
"}")
        self.restore_button_4.setText("")
        self.restore_button_4.setObjectName("restore_button_4")
        self.horizontalLayout_23.addWidget(self.restore_button_4)
        self.minimize_button_4 = QtWidgets.QPushButton(self.header_buttons_4)
        self.minimize_button_4.setMinimumSize(QtCore.QSize(15, 15))
        self.minimize_button_4.setMaximumSize(QtCore.QSize(16, 16))
        self.minimize_button_4.setStyleSheet("*{\n"
"border-radius:8px;\n"
"background-color:rgb(81, 244, 0)\n"
"\n"
"\n"
"}")
        self.minimize_button_4.setText("")
        self.minimize_button_4.setObjectName("minimize_button_4")
        self.horizontalLayout_23.addWidget(self.minimize_button_4)
        self.horizontalLayout_24.addWidget(self.header_buttons_4)
        self.login_body_frame = QtWidgets.QFrame(self.login_page)
        self.login_body_frame.setGeometry(QtCore.QRect(0, 33, 818, 671))
        self.login_body_frame.setMaximumSize(QtCore.QSize(818, 671))
        self.login_body_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.login_body_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.login_body_frame.setObjectName("login_body_frame")
        self.username_input = QtWidgets.QLineEdit(self.login_body_frame)
        self.username_input.setGeometry(QtCore.QRect(80, 130, 311, 41))
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.username_input.setFont(font)
        self.username_input.setStyleSheet("*{\n"
"color:white;\n"
"background-color: rgba(20, 20, 20,40);\n"
"border-bottom:2px solid  rgb(255, 23, 96);\n"
"}\n"
"\n"
"*:hover{\n"
"    background-color: rgba(20, 20, 20,100);\n"
"    border-bottom:2px solid  rgb(106, 59, 248);\n"
"}")
        self.username_input.setObjectName("username_input")
        self.password_input = QtWidgets.QLineEdit(self.login_body_frame)
        self.password_input.setGeometry(QtCore.QRect(80, 290, 321, 41))
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(12)
        self.password_input.setFont(font)
        self.password_input.setStyleSheet("*{\n"
"color:white;\n"
"background-color: rgba(20, 20, 20,40);\n"
"border-bottom:2px solid  rgb(255, 23, 96);\n"
"}\n"
"\n"
"*:hover{\n"
"    background-color: rgba(20, 20, 20,100);\n"
"    border-bottom:2px solid  rgb(106, 59, 248);\n"
"}")
        self.password_input.setEchoMode(QtWidgets.QLineEdit.PasswordEchoOnEdit)
        self.password_input.setObjectName("password_input")
        self.pushButton = QtWidgets.QPushButton(self.login_body_frame)
        self.pushButton.setGeometry(QtCore.QRect(130, 470, 211, 41))
        self.pushButton.setStyleSheet("*{\n"
"background-color: rgb(255, 23, 96);\n"
"color: rgb(234, 234, 234);\n"
"}\n"
"\n"
"*:hover{\n"
"    background-color: rgb(106, 59, 248);\n"
"}")
        self.pushButton.setObjectName("pushButton")
        self.image_background = QtWidgets.QLabel(self.login_body_frame)
        self.image_background.setGeometry(QtCore.QRect(-30, -20, 491, 701))
        self.image_background.setText("")
        self.image_background.setPixmap(QtGui.QPixmap("../../Downloads/esteb.jpg"))
        self.image_background.setScaledContents(True)
        self.image_background.setObjectName("image_background")
        self.image_background.raise_()
        self.username_input.raise_()
        self.password_input.raise_()
        self.pushButton.raise_()
        self.login_footer = QtWidgets.QFrame(self.login_page)
        self.login_footer.setGeometry(QtCore.QRect(0, 707, 141, 16))
        self.login_footer.setMaximumSize(QtCore.QSize(16777215, 20))
        self.login_footer.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.login_footer.setFrameShadow(QtWidgets.QFrame.Raised)
        self.login_footer.setObjectName("login_footer")
        self.verticalLayout_45 = QtWidgets.QVBoxLayout(self.login_footer)
        self.verticalLayout_45.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_45.setSpacing(2)
        self.verticalLayout_45.setObjectName("verticalLayout_45")
        self.grip_label_4 = QtWidgets.QLabel(self.login_footer)
        self.grip_label_4.setStyleSheet("color: rgb(236, 236, 236);\n"
"border:none;")
        self.grip_label_4.setObjectName("grip_label_4")
        self.verticalLayout_45.addWidget(self.grip_label_4)
        self.stackedWidget.addWidget(self.login_page)
        self.bot_page = QtWidgets.QWidget()
        self.bot_page.setObjectName("bot_page")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.bot_page)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(3)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.main_frame = QtWidgets.QFrame(self.bot_page)
        self.main_frame.setStyleSheet("")
        self.main_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.main_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.main_frame.setObjectName("main_frame")
        self.verticalLayout_29 = QtWidgets.QVBoxLayout(self.main_frame)
        self.verticalLayout_29.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_29.setSpacing(3)
        self.verticalLayout_29.setObjectName("verticalLayout_29")
        self.header_frame = QtWidgets.QFrame(self.main_frame)
        self.header_frame.setMinimumSize(QtCore.QSize(400, 20))
        self.header_frame.setMaximumSize(QtCore.QSize(16777215, 40))
        self.header_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.header_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.header_frame.setObjectName("header_frame")
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout(self.header_frame)
        self.horizontalLayout_16.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_16.setSpacing(5)
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.left_header_content = QtWidgets.QFrame(self.header_frame)
        self.left_header_content.setStyleSheet("background-color:none;")
        self.left_header_content.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.left_header_content.setFrameShadow(QtWidgets.QFrame.Raised)
        self.left_header_content.setObjectName("left_header_content")
        self.verticalLayout_30 = QtWidgets.QVBoxLayout(self.left_header_content)
        self.verticalLayout_30.setContentsMargins(9, 0, 0, 0)
        self.verticalLayout_30.setSpacing(3)
        self.verticalLayout_30.setObjectName("verticalLayout_30")
        self.label = QtWidgets.QLabel(self.left_header_content)
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(13)
        font.setBold(False)
        font.setWeight(50)
        self.label.setFont(font)
        self.label.setStyleSheet("color: rgb(255, 23, 96);")
        self.label.setObjectName("label")
        self.verticalLayout_30.addWidget(self.label)
        self.horizontalLayout_16.addWidget(self.left_header_content)
        self.header_buttons = QtWidgets.QFrame(self.header_frame)
        self.header_buttons.setMinimumSize(QtCore.QSize(15, 15))
        self.header_buttons.setMaximumSize(QtCore.QSize(400, 16777215))
        self.header_buttons.setStyleSheet("background-color:none;")
        self.header_buttons.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.header_buttons.setFrameShadow(QtWidgets.QFrame.Raised)
        self.header_buttons.setObjectName("header_buttons")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout(self.header_buttons)
        self.horizontalLayout_17.setContentsMargins(300, 0, 0, 0)
        self.horizontalLayout_17.setSpacing(3)
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.close_button = QtWidgets.QPushButton(self.header_buttons)
        self.close_button.setMinimumSize(QtCore.QSize(15, 15))
        self.close_button.setMaximumSize(QtCore.QSize(16, 16))
        self.close_button.setStyleSheet("*{\n"
"border-none;\n"
"border-radius:8px;\n"
"background-color:red;\n"
"\n"
"\n"
"}")
        self.close_button.setText("")
        self.close_button.setObjectName("close_button")
        self.horizontalLayout_17.addWidget(self.close_button)
        self.restore_button = QtWidgets.QPushButton(self.header_buttons)
        self.restore_button.setMinimumSize(QtCore.QSize(15, 15))
        self.restore_button.setMaximumSize(QtCore.QSize(16, 16))
        self.restore_button.setStyleSheet("*{\n"
"border-radius:8px;\n"
"\n"
"background-color: rgb(255, 142, 29);\n"
"\n"
"\n"
"}")
        self.restore_button.setText("")
        self.restore_button.setObjectName("restore_button")
        self.horizontalLayout_17.addWidget(self.restore_button)
        self.minimize_button = QtWidgets.QPushButton(self.header_buttons)
        self.minimize_button.setMinimumSize(QtCore.QSize(15, 15))
        self.minimize_button.setMaximumSize(QtCore.QSize(16, 16))
        self.minimize_button.setStyleSheet("*{\n"
"border-radius:8px;\n"
"background-color:rgb(81, 244, 0)\n"
"\n"
"\n"
"}")
        self.minimize_button.setText("")
        self.minimize_button.setObjectName("minimize_button")
        self.horizontalLayout_17.addWidget(self.minimize_button)
        self.horizontalLayout_16.addWidget(self.header_buttons)
        self.verticalLayout_29.addWidget(self.header_frame)
        self.body_frame = QtWidgets.QFrame(self.main_frame)
        self.body_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.body_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.body_frame.setObjectName("body_frame")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout(self.body_frame)
        self.horizontalLayout_18.setContentsMargins(0, 0, 0, 2)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.progress_and_status_frame = QtWidgets.QFrame(self.body_frame)
        self.progress_and_status_frame.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.progress_and_status_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.progress_and_status_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.progress_and_status_frame.setObjectName("progress_and_status_frame")
        self.verticalLayout_31 = QtWidgets.QVBoxLayout(self.progress_and_status_frame)
        self.verticalLayout_31.setContentsMargins(2, 2, 2, 2)
        self.verticalLayout_31.setObjectName("verticalLayout_31")
        self.hashtag_frame = QtWidgets.QFrame(self.progress_and_status_frame)
        self.hashtag_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.hashtag_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.hashtag_frame.setObjectName("hashtag_frame")
        self.verticalLayout_32 = QtWidgets.QVBoxLayout(self.hashtag_frame)
        self.verticalLayout_32.setContentsMargins(4, 4, 4, 4)
        self.verticalLayout_32.setSpacing(3)
        self.verticalLayout_32.setObjectName("verticalLayout_32")
        self.hashtag_title = QtWidgets.QFrame(self.hashtag_frame)
        self.hashtag_title.setStyleSheet("border:2px solid  rgb(59, 59, 59);")
        self.hashtag_title.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.hashtag_title.setFrameShadow(QtWidgets.QFrame.Raised)
        self.hashtag_title.setObjectName("hashtag_title")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout(self.hashtag_title)
        self.horizontalLayout_19.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_19.setSpacing(3)
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.liked_label = QtWidgets.QLabel(self.hashtag_title)
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.liked_label.setFont(font)
        self.liked_label.setStyleSheet("color: rgb(236, 236, 236);\n"
"border:none;")
        self.liked_label.setAlignment(QtCore.Qt.AlignCenter)
        self.liked_label.setObjectName("liked_label")
        self.horizontalLayout_19.addWidget(self.liked_label)
        self.verticalLayout_32.addWidget(self.hashtag_title)
        self.liked_progressBar = QtWidgets.QProgressBar(self.hashtag_frame)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.liked_progressBar.setFont(font)
        self.liked_progressBar.setStyleSheet("QProgressBar {\n"
"     border: 1px solid grey;\n"
"     border-radius: 2px;\n"
"     color:white;\n"
"     background-color: rgb(79, 79, 79);\n"
" }\n"
"\n"
" QProgressBar::chunk {\n"
"         background-color: rgb(17, 120, 255);\n"
"     width: 20px;\n"
" }\n"
"\n"
"\n"
"")
        self.liked_progressBar.setProperty("value", 24)
        self.liked_progressBar.setAlignment(QtCore.Qt.AlignCenter)
        self.liked_progressBar.setObjectName("liked_progressBar")
        self.verticalLayout_32.addWidget(self.liked_progressBar)
        self.like_listWidget = QtWidgets.QListWidget(self.hashtag_frame)
        font = QtGui.QFont()
        font.setFamily("Segoe UI Semibold")
        font.setBold(True)
        font.setWeight(75)
        self.like_listWidget.setFont(font)
        self.like_listWidget.setStyleSheet("\n"
"color: rgb(213, 213, 213);")
        self.like_listWidget.setTabKeyNavigation(False)
        self.like_listWidget.setWordWrap(True)
        self.like_listWidget.setObjectName("like_listWidget")
        item = QtWidgets.QListWidgetItem()
        self.like_listWidget.addItem(item)
        self.verticalLayout_32.addWidget(self.like_listWidget)
        self.verticalLayout_31.addWidget(self.hashtag_frame)
        self.content_separator_line = QtWidgets.QFrame(self.progress_and_status_frame)
        self.content_separator_line.setMaximumSize(QtCore.QSize(16777215, 1))
        self.content_separator_line.setStyleSheet("background-color:grey;")
        self.content_separator_line.setFrameShape(QtWidgets.QFrame.HLine)
        self.content_separator_line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.content_separator_line.setObjectName("content_separator_line")
        self.verticalLayout_31.addWidget(self.content_separator_line)
        self.target_user_frame = QtWidgets.QFrame(self.progress_and_status_frame)
        self.target_user_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.target_user_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.target_user_frame.setObjectName("target_user_frame")
        self.verticalLayout_33 = QtWidgets.QVBoxLayout(self.target_user_frame)
        self.verticalLayout_33.setContentsMargins(4, 4, 4, 4)
        self.verticalLayout_33.setSpacing(3)
        self.verticalLayout_33.setObjectName("verticalLayout_33")
        self.commented_title_2 = QtWidgets.QFrame(self.target_user_frame)
        self.commented_title_2.setStyleSheet("border:2px solid  rgb(59, 59, 59);")
        self.commented_title_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.commented_title_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.commented_title_2.setObjectName("commented_title_2")
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout(self.commented_title_2)
        self.horizontalLayout_20.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_20.setSpacing(3)
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.commented_label = QtWidgets.QLabel(self.commented_title_2)
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(12)
        font.setBold(False)
        font.setWeight(50)
        self.commented_label.setFont(font)
        self.commented_label.setStyleSheet("color: rgb(236, 236, 236);\n"
"border:none;")
        self.commented_label.setAlignment(QtCore.Qt.AlignCenter)
        self.commented_label.setObjectName("commented_label")
        self.horizontalLayout_20.addWidget(self.commented_label)
        self.verticalLayout_33.addWidget(self.commented_title_2)
        self.comments_progressbar = QtWidgets.QProgressBar(self.target_user_frame)
        self.comments_progressbar.setStyleSheet("QProgressBar {\n"
"     border: 1px solid grey;\n"
"     border-radius: 2px;\n"
"     color:white;\n"
"     background-color: rgb(79, 79, 79);\n"
" }\n"
"\n"
" QProgressBar::chunk {\n"
"     background-color: rgb(255, 23, 96);\n"
"     width: 20px;\n"
" }\n"
"")
        self.comments_progressbar.setProperty("value", 24)
        self.comments_progressbar.setAlignment(QtCore.Qt.AlignCenter)
        self.comments_progressbar.setObjectName("comments_progressbar")
        self.verticalLayout_33.addWidget(self.comments_progressbar)
        self.comment_listwidget = QtWidgets.QListWidget(self.target_user_frame)
        font = QtGui.QFont()
        font.setFamily("Segoe UI Semibold")
        font.setBold(True)
        font.setWeight(75)
        self.comment_listwidget.setFont(font)
        self.comment_listwidget.setStyleSheet("\n"
"color: rgb(213, 213, 213);")
        self.comment_listwidget.setTabKeyNavigation(False)
        self.comment_listwidget.setWordWrap(True)
        self.comment_listwidget.setObjectName("comment_listwidget")
        item = QtWidgets.QListWidgetItem()
        self.comment_listwidget.addItem(item)
        self.verticalLayout_33.addWidget(self.comment_listwidget)
        self.verticalLayout_31.addWidget(self.target_user_frame)
        self.footer_frame = QtWidgets.QFrame(self.progress_and_status_frame)
        self.footer_frame.setMaximumSize(QtCore.QSize(16777215, 20))
        self.footer_frame.setStyleSheet("border-radius:2px;")
        self.footer_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.footer_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.footer_frame.setObjectName("footer_frame")
        self.verticalLayout_34 = QtWidgets.QVBoxLayout(self.footer_frame)
        self.verticalLayout_34.setContentsMargins(-1, 0, 0, 0)
        self.verticalLayout_34.setSpacing(2)
        self.verticalLayout_34.setObjectName("verticalLayout_34")
        self.grip_label = QtWidgets.QLabel(self.footer_frame)
        self.grip_label.setStyleSheet("color: rgb(236, 236, 236);\n"
"border:none;")
        self.grip_label.setObjectName("grip_label")
        self.verticalLayout_34.addWidget(self.grip_label)
        self.verticalLayout_31.addWidget(self.footer_frame)
        self.horizontalLayout_18.addWidget(self.progress_and_status_frame)
        self.line = QtWidgets.QFrame(self.body_frame)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_18.addWidget(self.line)
        self.logged_user_frame = QtWidgets.QFrame(self.body_frame)
        self.logged_user_frame.setMaximumSize(QtCore.QSize(400, 16777215))
        self.logged_user_frame.setAutoFillBackground(False)
        self.logged_user_frame.setStyleSheet("background-color:rgb(35,35,35);")
        self.logged_user_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.logged_user_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.logged_user_frame.setObjectName("logged_user_frame")
        self.verticalLayout_35 = QtWidgets.QVBoxLayout(self.logged_user_frame)
        self.verticalLayout_35.setContentsMargins(2, 2, 2, 2)
        self.verticalLayout_35.setObjectName("verticalLayout_35")
        self.user_frame = QtWidgets.QFrame(self.logged_user_frame)
        self.user_frame.setStyleSheet("border: 1px solid grey;")
        self.user_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.user_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.user_frame.setObjectName("user_frame")
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout(self.user_frame)
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self.user_avatar = QtWidgets.QLabel(self.user_frame)
        self.user_avatar.setMaximumSize(QtCore.QSize(50, 50))
        self.user_avatar.setStyleSheet("border:2px solid  rgb(17, 120, 255);")
        self.user_avatar.setText("")
        self.user_avatar.setPixmap(QtGui.QPixmap("rach1.jpg"))
        self.user_avatar.setScaledContents(True)
        self.user_avatar.setObjectName("user_avatar")
        self.horizontalLayout_21.addWidget(self.user_avatar)
        self.username = QtWidgets.QLabel(self.user_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(13)
        font.setBold(False)
        font.setWeight(50)
        self.username.setFont(font)
        self.username.setStyleSheet("color: rgb(173, 173, 173);\n"
"border:none;")
        self.username.setWordWrap(True)
        self.username.setObjectName("username")
        self.horizontalLayout_21.addWidget(self.username)
        self.verticalLayout_35.addWidget(self.user_frame)
        self.live_update_frame = QtWidgets.QFrame(self.logged_user_frame)
        self.live_update_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.live_update_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.live_update_frame.setObjectName("live_update_frame")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.live_update_frame)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.followers_frame = QtWidgets.QFrame(self.live_update_frame)
        self.followers_frame.setStyleSheet("background-color:none;")
        self.followers_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.followers_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.followers_frame.setObjectName("followers_frame")
        self.verticalLayout_36 = QtWidgets.QVBoxLayout(self.followers_frame)
        self.verticalLayout_36.setContentsMargins(-1, 2, 2, 2)
        self.verticalLayout_36.setObjectName("verticalLayout_36")
        self.followers_label = QtWidgets.QLabel(self.followers_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.followers_label.setFont(font)
        self.followers_label.setStyleSheet("color: rgb(255, 23, 96);")
        self.followers_label.setObjectName("followers_label")
        self.verticalLayout_36.addWidget(self.followers_label)
        self.follower_count = QtWidgets.QLabel(self.followers_frame)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.follower_count.setFont(font)
        self.follower_count.setStyleSheet("color: rgb(136, 136, 136);")
        self.follower_count.setObjectName("follower_count")
        self.verticalLayout_36.addWidget(self.follower_count)
        self.horizontalLayout_3.addWidget(self.followers_frame)
        self.follower_live_statistics = QtWidgets.QFrame(self.live_update_frame)
        self.follower_live_statistics.setStyleSheet("background-color:none;")
        self.follower_live_statistics.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.follower_live_statistics.setFrameShadow(QtWidgets.QFrame.Raised)
        self.follower_live_statistics.setObjectName("follower_live_statistics")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.follower_live_statistics)
        self.verticalLayout.setContentsMargins(3, 0, 9, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.stats_title = QtWidgets.QLabel(self.follower_live_statistics)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.stats_title.setFont(font)
        self.stats_title.setStyleSheet("color: rgb(236, 236, 236);")
        self.stats_title.setAlignment(QtCore.Qt.AlignCenter)
        self.stats_title.setObjectName("stats_title")
        self.verticalLayout.addWidget(self.stats_title)
        self.stat_indicator = QtWidgets.QLabel(self.follower_live_statistics)
        self.stat_indicator.setMaximumSize(QtCore.QSize(16777215, 35))
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.stat_indicator.setFont(font)
        self.stat_indicator.setStyleSheet("color: rgb(136, 136, 136);")
        self.stat_indicator.setText("")
        self.stat_indicator.setPixmap(QtGui.QPixmap("../../Downloads/decrease.png"))
        self.stat_indicator.setScaledContents(False)
        self.stat_indicator.setAlignment(QtCore.Qt.AlignCenter)
        self.stat_indicator.setObjectName("stat_indicator")
        self.verticalLayout.addWidget(self.stat_indicator)
        self.gaiin_lost = QtWidgets.QLabel(self.follower_live_statistics)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.gaiin_lost.setFont(font)
        self.gaiin_lost.setStyleSheet("color: rgb(136, 136, 136);")
        self.gaiin_lost.setAlignment(QtCore.Qt.AlignCenter)
        self.gaiin_lost.setObjectName("gaiin_lost")
        self.verticalLayout.addWidget(self.gaiin_lost)
        self.horizontalLayout_3.addWidget(self.follower_live_statistics)
        self.following_frame = QtWidgets.QFrame(self.live_update_frame)
        self.following_frame.setStyleSheet("background-color:none;")
        self.following_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.following_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.following_frame.setObjectName("following_frame")
        self.verticalLayout_37 = QtWidgets.QVBoxLayout(self.following_frame)
        self.verticalLayout_37.setContentsMargins(9, 2, 2, 2)
        self.verticalLayout_37.setObjectName("verticalLayout_37")
        self.following_label = QtWidgets.QLabel(self.following_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(9)
        font.setBold(True)
        font.setWeight(75)
        self.following_label.setFont(font)
        self.following_label.setStyleSheet("color:rgb(17, 120, 255);\n"
"border:none;\n"
"")
        self.following_label.setAlignment(QtCore.Qt.AlignCenter)
        self.following_label.setObjectName("following_label")
        self.verticalLayout_37.addWidget(self.following_label)
        self.following_count = QtWidgets.QLabel(self.following_frame)
        self.following_count.setStyleSheet("color: rgb(180, 180, 180);")
        self.following_count.setAlignment(QtCore.Qt.AlignCenter)
        self.following_count.setObjectName("following_count")
        self.verticalLayout_37.addWidget(self.following_count)
        self.horizontalLayout_3.addWidget(self.following_frame)
        self.verticalLayout_35.addWidget(self.live_update_frame)
        self.content_separator_line_2 = QtWidgets.QFrame(self.logged_user_frame)
        self.content_separator_line_2.setMaximumSize(QtCore.QSize(396, 1))
        self.content_separator_line_2.setStyleSheet("\n"
"background-color: rgb(255, 23, 96);")
        self.content_separator_line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.content_separator_line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.content_separator_line_2.setObjectName("content_separator_line_2")
        self.verticalLayout_35.addWidget(self.content_separator_line_2)
        self.status_and_profile_frame = QtWidgets.QFrame(self.logged_user_frame)
        self.status_and_profile_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.status_and_profile_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.status_and_profile_frame.setObjectName("status_and_profile_frame")
        self.verticalLayout_38 = QtWidgets.QVBoxLayout(self.status_and_profile_frame)
        self.verticalLayout_38.setObjectName("verticalLayout_38")
        self.status_listwidget = QtWidgets.QListWidget(self.status_and_profile_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(10)
        font.setBold(False)
        font.setWeight(50)
        self.status_listwidget.setFont(font)
        self.status_listwidget.setStyleSheet("\n"
"color: rgb(213, 213, 213);")
        self.status_listwidget.setTabKeyNavigation(False)
        self.status_listwidget.setWordWrap(True)
        self.status_listwidget.setObjectName("status_listwidget")
        item = QtWidgets.QListWidgetItem()
        self.status_listwidget.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.status_listwidget.addItem(item)
        self.verticalLayout_38.addWidget(self.status_listwidget)
        self.verticalLayout_35.addWidget(self.status_and_profile_frame)
        self.add_hashtag_frame = QtWidgets.QFrame(self.logged_user_frame)
        self.add_hashtag_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.add_hashtag_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.add_hashtag_frame.setObjectName("add_hashtag_frame")
        self.verticalLayout_39 = QtWidgets.QVBoxLayout(self.add_hashtag_frame)
        self.verticalLayout_39.setContentsMargins(4, 4, 4, 4)
        self.verticalLayout_39.setSpacing(3)
        self.verticalLayout_39.setObjectName("verticalLayout_39")
        self.hashtag_input = QtWidgets.QTextEdit(self.add_hashtag_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(10)
        self.hashtag_input.setFont(font)
        self.hashtag_input.setStyleSheet("\n"
"color: rgb(179, 179, 179);\n"
"border-bottom:2px solid  rgb(59, 59, 59);")
        self.hashtag_input.setObjectName("hashtag_input")
        self.verticalLayout_39.addWidget(self.hashtag_input)
        self.verticalLayout_35.addWidget(self.add_hashtag_frame)
        self.add_comments_frame = QtWidgets.QFrame(self.logged_user_frame)
        self.add_comments_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.add_comments_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.add_comments_frame.setObjectName("add_comments_frame")
        self.verticalLayout_40 = QtWidgets.QVBoxLayout(self.add_comments_frame)
        self.verticalLayout_40.setContentsMargins(4, 4, 4, 4)
        self.verticalLayout_40.setSpacing(3)
        self.verticalLayout_40.setObjectName("verticalLayout_40")
        self.add_comments_input = QtWidgets.QTextEdit(self.add_comments_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(10)
        self.add_comments_input.setFont(font)
        self.add_comments_input.setStyleSheet("\n"
"color: rgb(179, 179, 179);\n"
"border-bottom:2px solid  rgb(255, 23, 96);")
        self.add_comments_input.setObjectName("add_comments_input")
        self.verticalLayout_40.addWidget(self.add_comments_input)
        self.verticalLayout_35.addWidget(self.add_comments_frame)
        self.target_usernames_frame = QtWidgets.QFrame(self.logged_user_frame)
        self.target_usernames_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.target_usernames_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.target_usernames_frame.setObjectName("target_usernames_frame")
        self.verticalLayout_41 = QtWidgets.QVBoxLayout(self.target_usernames_frame)
        self.verticalLayout_41.setContentsMargins(4, 4, 4, 4)
        self.verticalLayout_41.setSpacing(3)
        self.verticalLayout_41.setObjectName("verticalLayout_41")
        self.targetusernames_input = QtWidgets.QTextEdit(self.target_usernames_frame)
        font = QtGui.QFont()
        font.setFamily("Sitka Display")
        font.setPointSize(10)
        self.targetusernames_input.setFont(font)
        self.targetusernames_input.setStyleSheet("\n"
"color: rgb(179, 179, 179);\n"
"border-bottom:2px solid  rgb(59, 59, 59);")
        self.targetusernames_input.setObjectName("targetusernames_input")
        self.verticalLayout_41.addWidget(self.targetusernames_input)
        self.verticalLayout_35.addWidget(self.target_usernames_frame)
        self.start_pause_button = QtWidgets.QFrame(self.logged_user_frame)
        self.start_pause_button.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.start_pause_button.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.start_pause_button.setFrameShadow(QtWidgets.QFrame.Raised)
        self.start_pause_button.setObjectName("start_pause_button")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.start_pause_button)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.start_button = QtWidgets.QPushButton(self.start_pause_button)
        self.start_button.setMaximumSize(QtCore.QSize(200, 16777215))
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(12)
        self.start_button.setFont(font)
        self.start_button.setStyleSheet("*{\n"
"background-color: rgb(255, 23, 96);\n"
"color: rgb(234, 234, 234);\n"
"}\n"
"\n"
"*:hover{\n"
"    background-color: rgb(106, 59, 248);\n"
"}")
        self.start_button.setObjectName("start_button")
        self.horizontalLayout_2.addWidget(self.start_button)
        self.logout_button = QtWidgets.QPushButton(self.start_pause_button)
        self.logout_button.setMaximumSize(QtCore.QSize(200, 16777215))
        font = QtGui.QFont()
        font.setFamily("Sitka Heading")
        font.setPointSize(12)
        self.logout_button.setFont(font)
        self.logout_button.setStyleSheet("*{\n"
" background-color: rgb(106, 59, 248);\n"
"color: rgb(234, 234, 234);\n"
"}\n"
"\n"
"*:hover{\n"
"\n"
"    background-color: rgb(255, 23, 96);\n"
"}")
        self.logout_button.setObjectName("logout_button")
        self.horizontalLayout_2.addWidget(self.logout_button)
        self.verticalLayout_35.addWidget(self.start_pause_button)
        self.horizontalLayout_18.addWidget(self.logged_user_frame)
        self.verticalLayout_29.addWidget(self.body_frame)
        self.horizontalLayout.addWidget(self.main_frame)
        self.stackedWidget.addWidget(self.bot_page)
        self.verticalLayout_43.addWidget(self.stackedWidget)
        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)
        self.stackedWidget.setCurrentIndex(2)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.connection_label.setText(_translate("MainWindow", "Connecting to database ..."))
        self.label_4.setText(_translate("MainWindow", "Natalie Bot"))
        self.username_input.setPlaceholderText(_translate("MainWindow", "Enter your username"))
        self.password_input.setPlaceholderText(_translate("MainWindow", "Enter your password"))
        self.pushButton.setText(_translate("MainWindow", "Login"))
        self.grip_label_4.setText(_translate("MainWindow", "can\'t resize a login window"))
        self.label.setText(_translate("MainWindow", "Natalie Bot"))
        self.liked_label.setText(_translate("MainWindow", "Liked Today"))
        __sortingEnabled = self.like_listWidget.isSortingEnabled()
        self.like_listWidget.setSortingEnabled(False)
        item = self.like_listWidget.item(0)
        item.setText(_translate("MainWindow", "like this user post on 12 june 2020"))
        self.like_listWidget.setSortingEnabled(__sortingEnabled)
        self.commented_label.setText(_translate("MainWindow", "Commented Today"))
        __sortingEnabled = self.comment_listwidget.isSortingEnabled()
        self.comment_listwidget.setSortingEnabled(False)
        item = self.comment_listwidget.item(0)
        item.setText(_translate("MainWindow", "like this user post on 12 june 2020"))
        self.comment_listwidget.setSortingEnabled(__sortingEnabled)
        self.grip_label.setText(_translate("MainWindow", "Grip to Resize window"))
        self.username.setText(_translate("MainWindow", "hey i\'m natalie \n"
""))
        self.followers_label.setText(_translate("MainWindow", "Followers"))
        self.follower_count.setText(_translate("MainWindow", "5000000"))
        self.stats_title.setText(_translate("MainWindow", "live follower stats"))
        self.gaiin_lost.setText(_translate("MainWindow", "Gained 50 today"))
        self.following_label.setText(_translate("MainWindow", "Following"))
        self.following_count.setText(_translate("MainWindow", "5000"))
        __sortingEnabled = self.status_listwidget.isSortingEnabled()
        self.status_listwidget.setSortingEnabled(False)
        item = self.status_listwidget.item(0)
        item.setText(_translate("MainWindow", "logging you in"))
        item = self.status_listwidget.item(1)
        item.setText(_translate("MainWindow", "Getting recent hashtag posts"))
        self.status_listwidget.setSortingEnabled(__sortingEnabled)
        self.hashtag_input.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sitka Display\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:\'MS Shell Dlg 2\'; font-size:8.25pt;\"><br /></p></body></html>"))
        self.hashtag_input.setPlaceholderText(_translate("MainWindow", "Enter or paste hashtags"))
        self.add_comments_input.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sitka Display\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:\'MS Shell Dlg 2\'; font-size:8.25pt;\"><br /></p></body></html>"))
        self.add_comments_input.setPlaceholderText(_translate("MainWindow", "Enter or paste comments"))
        self.targetusernames_input.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sitka Display\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:\'MS Shell Dlg 2\'; font-size:8.25pt;\"><br /></p></body></html>"))
        self.targetusernames_input.setPlaceholderText(_translate("MainWindow", "Enter or paste target usernames"))
        self.start_button.setText(_translate("MainWindow", "Start Bot"))
        self.logout_button.setText(_translate("MainWindow", "logout"))



import time

from natalie import *

# globals

GLOBAL_STATE=0
max_likes=50
liked=0

loaded_img=False
from PyQt5 import QtCore
from PyQt5.QtGui import QColor
from PyQt5.QtWidgets import QWidget, QHBoxLayout, \
    QGraphicsDropShadowEffect, QPushButton, QApplication, QComboBox,QSizeGrip
from PyQt5 import QtCore, QtGui, QtWidgets
import cv2

from PyQt5.QtWidgets import *
from PyQt5 import QtCore, QtGui
from PyQt5.QtGui import *
from PyQt5.QtCore import *
import pymongo
import threading

scroll_style_sheet=''' QScrollBar:vertical {
	border: none;
    background: rgb(45, 45, 68);
    width: 14px;
    margin: 15px 0 15px 0;
	border-radius: 0px;
 }

/*  HANDLE BAR VERTICAL */
QScrollBar::handle:vertical {	
	background-color: rgb(80, 80, 122);
	min-height: 30px;
	border-radius: 7px;
}
QScrollBar::handle:vertical:hover{	
	background-color: rgb(255, 0, 127);
}
QScrollBar::handle:vertical:pressed {	
	background-color: rgb(185, 0, 92);
}

/* BTN TOP - SCROLLBAR */
QScrollBar::sub-line:vertical {
	border: none;
	background-color: rgb(59, 59, 90);
	height: 15px;
	border-top-left-radius: 7px;
	border-top-right-radius: 7px;
	subcontrol-position: top;
	subcontrol-origin: margin;
}
QScrollBar::sub-line:vertical:hover {	
	background-color: rgb(255, 0, 127);
}
QScrollBar::sub-line:vertical:pressed {	
	background-color: rgb(185, 0, 92);
}

/* BTN BOTTOM - SCROLLBAR */
QScrollBar::add-line:vertical {
	border: none;
	background-color: rgb(59, 59, 90);
	height: 15px;
	border-bottom-left-radius: 7px;
	border-bottom-right-radius: 7px;
	subcontrol-position: bottom;
	subcontrol-origin: margin;
}
QScrollBar::add-line:vertical:hover {	
	background-color: rgb(255, 0, 127);
}
QScrollBar::add-line:vertical:pressed {	
	background-color: rgb(185, 0, 92);
}

/* RESET ARROW */
QScrollBar::up-arrow:vertical, QScrollBar::down-arrow:vertical {
	background: none;
}
QScrollBar::add-page:vertical, QScrollBar::sub-page:vertical {
	background: none;
}


'''

class UIFunctions(MainWindow):
    ## ==> MAXIMIZE RESTORE FUNCTION

    def maximize_restore(self):
        global GLOBAL_STATE

        status = GLOBAL_STATE

        self.ui.close_button.setToolTip("close")
        self.ui.close_button_4.setToolTip("close")

        # IF NOT MAXIMIZED
        if status == 0:
            self.showMaximized()

            # SET GLOBAL TO 1
            GLOBAL_STATE = 1

            # IF MAXIMIZED REMOVE MARGINS AND BORDER RADIUS
            # self.ui.main_frame.setContentsMargins(0, 0, 0, 0)
            # self.ui.main_frame.setStyleSheet("background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(42, 44, 111, 255), stop:0.521368 rgba(28, 29, 73, 255)); border-radius: 0px;")
            self.ui.restore_button.setToolTip("Restore")

        else:
            GLOBAL_STATE = 0
            self.showNormal()
            self.resize(self.width()+1, self.height()+1)
            # self.ui.main_frame.setContentsMargins(10, 10, 10, 10)
            # self.ui.main_frame.setStyleSheet("background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(42, 44, 111, 255), stop:0.521368 rgba(28, 29, 73, 255)); border-radius: 10px;")

            self.ui.minimize_button.setToolTip("minimize")

            self.ui.minimize_button_4.setToolTip("minimize")

    ## ==> UI DEFINITIONS
    def uiDefinitions(self):

        # REMOVE TITLE BAR
        self.setWindowFlag(QtCore.Qt.FramelessWindowHint)
        self.setAttribute(QtCore.Qt.WA_TranslucentBackground)

        # SET DROPSHADOW WINDOW
        self.shadow = QGraphicsDropShadowEffect(self)
        self.shadow.setBlurRadius(20)
        self.shadow.setXOffset(0)
        self.shadow.setYOffset(0)
        self.shadow.setColor(QColor(0, 0, 0, 100))

        # APPLY DROPSHADOW TO FRAME
        self.ui.main_frame.setGraphicsEffect(self.shadow)

        self.ui.login_header_frame.setGraphicsEffect(self.shadow)

        # # MAXIMIZE / RESTORE
        self.ui.restore_button.clicked.connect(lambda: UIFunctions.maximize_restore(self))
        #
        # # MINIMIZE
        self.ui.minimize_button.clicked.connect(lambda: self.showMinimized())
        #
        # # CLOSE
        self.ui.close_button.clicked.connect(lambda: self.close())

        '''login page'''

        # # MAXIMIZE / RESTORE
        # self.ui.restore_button_4.clicked.connect(lambda: UIFunctions.maximize_restore(self))
        #
        # # MINIMIZE
        self.ui.minimize_button_4.clicked.connect(lambda: self.showMinimized())
        #
        # # CLOSE
        self.ui.close_button_4.clicked.connect(lambda: self.close())

        # ==> CREATE SIZE GRIP TO RESIZE WINDOW
        self.sizegrip = QSizeGrip(self.ui.footer_frame)
        self.sizegrip.setStyleSheet("QSizeGrip { width: 10px; height: 10px; margin: 5px } QSizeGrip:hover { background-color: rgb(50, 42, 94) }")
        self.sizegrip.setToolTip("Resize Window")

    def change_avatar(self):

        self.ui.user_avatar.setStyleSheet('''*{border:2px solid  rgb(17, 120, 255);}\n
                                            *:hover{border:3px solid rgb(255, 23, 96);}''')

    def loading_page(self):
        self.setStyleSheet("\n"
"background-color: rgba(59, 59, 59,0);\n"
"border-radius:5px;")

        self.resize(670, 331)

        self.ui.loading_image.setGeometry(QtCore.QRect(30,10, 651, 331))

        self.ui.loading_bar.setGeometry(QtCore.QRect(180,150, 343, 24))

        self.ui.connection_label.setGeometry(QtCore.QRect(240,240, 241, 61))

    def set_current_win(self,win):
        self.ui.stackedWidget.setCurrentIndex(win)

    def login_page(self):
        self.move(500,100)

        self.setStyleSheet("\n"
                           "background-color: rgba(59, 59, 59,0);\n"
                           "border-radius:5px;")

        self.ui.login_header_frame.setStyleSheet("\n"
                           "background-color: rgba(59, 59, 59,255);\n"
                           "border-radius:5px;")

        self.resize(451,737)

        self.ui.login_body_frame.setMaximumSize(QtCore.QSize(451,737))

    def main_page(self):
        self.move(500, 100)

        self.ui.hashtag_title.setStyleSheet("border:none;")
        self.ui.commented_title_2.setStyleSheet("border:none;")

        self.setStyleSheet("\n"
                           "background-color: rgba(59, 59, 59,35);\n"
                           "border-radius:5px;")

        self.ui.header_frame.setStyleSheet("\n"
                                           "background-color: rgba(59, 59, 59,255);\n"
                                           "border-radius:5px;")

        self.resize(542,614)
        self.setMaximumSize(QtCore.QSize(16777215, 16777215))

    def set_blur(self):
        self.blur_effect = QGraphicsBlurEffect()

        # setting blur radius
        self.blur_effect.setBlurRadius(4)

        self.ui.hashtag_frame.setGraphicsEffect(self.blur_effect)

    def edit_verical_scrollbar(self):

        scroll_bar = QScrollBar(self)

        # setting style sheet to the scroll bar
        scroll_bar.setStyleSheet(scroll_style_sheet)

        # setting vertical scroll bar to it
        self.ui.hashtag_input.setVerticalScrollBar(scroll_bar)

        scroll_bar = QScrollBar(self)

        # setting style sheet to the scroll bar
        scroll_bar.setStyleSheet(scroll_style_sheet)

        self.ui.add_comments_input.setVerticalScrollBar(scroll_bar)

        scroll_bar = QScrollBar(self)

        # setting style sheet to the scroll bar
        scroll_bar.setStyleSheet(scroll_style_sheet)

        self.ui.targetusernames_input.setVerticalScrollBar(scroll_bar)

        scroll_bar = QScrollBar(self)

        # setting style sheet to the scroll bar
        scroll_bar.setStyleSheet(scroll_style_sheet)

        self.ui.like_listWidget.setVerticalScrollBar(scroll_bar)

        scroll_bar = QScrollBar(self)

        # setting style sheet to the scroll bar
        scroll_bar.setStyleSheet(scroll_style_sheet)

        self.ui.comment_listwidget.setVerticalScrollBar(scroll_bar)

        scroll_bar = QScrollBar(self)

        # setting style sheet to the scroll bar
        scroll_bar.setStyleSheet(scroll_style_sheet)

        self.ui.status_listwidget.setVerticalScrollBar(scroll_bar)

    def add_scroll_status(self,value):

        print('''      .'\   /`.
         .'.-.`-'.-.`.
    ..._:   .-. .-.   :_...
  .'    '-.(o ) (o ).-'    `.
 :  _    _ _`~(_)~`_ _    _  :
:  /:   ' .-=_   _=-. `   ;\  :
:   :|-.._  '     `  _..-|:   :
 :   `:| |`:-:-.-:-:'| |:'   :
  `.   `.| | | | | | |.'   .'
    `.   `-:_| | |_:-'   .'
 jgs  `-._   ````    _.-'
          ``-------''''')

        self.ui.status_listwidget.setStyleSheet("color: rgb(0,170,255)")
        self.ui.status_listwidget.addItem(value)
        self.ui.status_listwidget.scrollToBottom()

        if "successfully liked" in value:
            print(f"found liking in value {value}")
            value=value.split("|")
            bar_val=int(value[1])

            self.ui.liked_progressBar.setValue(bar_val)

            self.ui.like_listWidget.addItem(value[0])
            self.ui.like_listWidget.scrollToBottom()

        if "maximum limit of 1000 likes" in value:
            bar_val=round(float(value.split("[")[1].split("]")[0].replace("%","")))

            self.ui.liked_progressBar.setValue(bar_val)

            self.ui.like_listWidget.addItem(value)
            self.ui.like_listWidget.scrollToBottom()

        if "like function" in value:
            value=value.split("sleep")[0]

            self.ui.like_listWidget.addItem(value)
            self.ui.like_listWidget.scrollToBottom()

        if "successfully commented" in value:
            value =value.split("|")
            bar_val=int(value[1])
            self.ui.comments_progressbar.setValue(bar_val)

            self.ui.comment_listwidget.addItem(value[0])

            self.ui.comment_listwidget.scrollToBottom()

        if "maximum limit of 200 comments" in value:
            bar_val = round(float(value.split("[")[1].split("]")[0].replace("%", "")))

            self.ui.comments_progressbar.setValue(bar_val)

            self.ui.comment_listwidget.addItem(value)

            self.ui.comment_listwidget.scrollToBottom()

    ## RETURN STATUS IF WINDOWS IS MAXIMIZE OR RESTAURED
    def returnStatus():
        return GLOBAL_STATE





